==> apache-gluten-1.3.0-incubating-src.tar.gz: incubator-gluten-1.3.0/gluten-substrait/src/main/java/org/apache/gluten/substrait/type/ListNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.gluten.substrait.type;

import io.substrait.proto.Type;

import java.io.Serializable;

public class ListNode implements TypeNode, Serializable {
  private final Boolean nullable;
  private final TypeNode nestedType;

  public ListNode(Boolean nullable, TypeNode nestedType) {
    this.nullable = nullable;
    this.nestedType = nestedType;
  }

  // It's used in ExplodeTransformer to determine output datatype from children.
  public TypeNode getNestedType() {
    return nestedType;
  }

  @Override
  public Type toProtobuf() {
    Type.List.Builder listBuilder = Type.List.newBuilder();
    listBuilder.setType(nestedType.toProtobuf());
    listBuilder.setNullability(
        nullable ? Type.Nullability.NULLABILITY_NULLABLE : Type.Nullability.NULLABILITY_REQUIRED);

    Type.Builder builder = Type.newBuilder();
    builder.setList(listBuilder.build());
    return builder.build();
  }
}

==> apache-gluten-1.5.0-incubating-src.tar.gz: incubator-gluten-1.5.0/gluten-substrait/src/main/java/org/apache/gluten/substrait/type/ListNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.gluten.substrait.type;

import io.substrait.proto.Type;

public class ListNode extends TypeNode {
  private final TypeNode nestedType;

  public ListNode(Boolean nullable, TypeNode nestedType) {
    super(nullable);
    this.nestedType = nestedType;
  }

  // It's used in ExplodeTransformer to determine output datatype from children.
  public TypeNode getNestedType() {
    return nestedType;
  }

  @Override
  public Type toProtobuf() {
    Type.List.Builder listBuilder = Type.List.newBuilder();
    listBuilder.setType(nestedType.toProtobuf());
    listBuilder.setNullability(
        nullable ? Type.Nullability.NULLABILITY_NULLABLE : Type.Nullability.NULLABILITY_REQUIRED);

    Type.Builder builder = Type.newBuilder();
    builder.setList(listBuilder.build());
    return builder.build();
  }
}
